gui Package
===========

:mod:`admin` Module
-------------------

.. automodule:: stoq.gui.admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`accounts` Module
----------------------

.. automodule:: stoq.gui.accounts
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`calendar` Module
----------------------

.. automodule:: stoq.gui.calendar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`config` Module
--------------------

.. automodule:: stoq.gui.config
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`financial` Module
-----------------------

.. automodule:: stoq.gui.financial
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventory` Module
-----------------------

.. automodule:: stoq.gui.inventory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`launcher` Module
----------------------

.. automodule:: stoq.gui.launcher
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payable` Module
---------------------

.. automodule:: stoq.gui.payable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pos` Module
-----------------

.. automodule:: stoq.gui.pos
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`production` Module
------------------------

.. automodule:: stoq.gui.production
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchase` Module
----------------------

.. automodule:: stoq.gui.purchase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`receivable` Module
------------------------

.. automodule:: stoq.gui.receivable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sales` Module
-------------------

.. automodule:: stoq.gui.sales
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`services` Module
----------------------

.. automodule:: stoq.gui.services
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stock` Module
--------------------

.. automodule:: stoq.gui.stock
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`till` Module
------------------

.. automodule:: stoq.gui.till
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`update` Module
--------------------

.. automodule:: stoq.gui.update
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`welcomedialog` Module
---------------------------

.. automodule:: stoq.gui.welcomedialog
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

    stoq.gui.shell
